@@ -1,3 +1,6 @@
+proc load_plugins {} {
+}
+
 proc read_files {} {
 
 }
@@ -18,7 +21,7 @@ proc set_params {} {
 }
 
 proc synth {top} {
-synth_ice40  -top $top
+synth_ice40 some yosys_synth_options -top $top
 }
 
 set top top_module
