@@ -1,5 +1,5 @@
 import os
-from edalize_common import make_edalize_test, tests_dir
+from .edalize_common import make_edalize_test, tests_dir
 
 
 def test_xcelium(make_edalize_test):
